@@ -145,7 +145,7 @@ describe 'magnum::api' do
       end
 
       let(:platform_params) do
-        case facts[:osfamily]
+        case facts[:os]['family']
         when 'Debian'
           { :api_package => 'magnum-api',
             :api_service => 'magnum-api' }
