@@ -23,7 +23,7 @@ describe 'magnum::client' do
       end
 
       let(:platform_params) do
-        case facts[:osfamily]
+        case facts[:os]['family']
         when 'Debian'
           { :client_package_name => 'python3-magnumclient' }
         when 'RedHat'
