@@ -36,6 +36,7 @@ describe 'magnum' do
           :heartbeat_timeout_threshold     => '<SERVICE DEFAULT>',
           :heartbeat_rate                  => '<SERVICE DEFAULT>',
           :heartbeat_in_pthread            => '<SERVICE DEFAULT>',
+          :rabbit_qos_prefetch_count       => '<SERVICE DEFAULT>',
           :rabbit_use_ssl                  => '<SERVICE DEFAULT>',
           :kombu_reconnect_delay           => '<SERVICE DEFAULT>',
           :kombu_failover_strategy         => '<SERVICE DEFAULT>',
@@ -50,6 +51,7 @@ describe 'magnum' do
           :rabbit_quorum_delivery_limit    => '<SERVICE DEFAULT>',
           :rabbit_quorum_max_memory_length => '<SERVICE DEFAULT>',
           :rabbit_quorum_max_memory_bytes  => '<SERVICE DEFAULT>',
+          :enable_cancel_on_failover       => '<SERVICE DEFAULT>',
         )
       end
 
@@ -57,7 +59,9 @@ describe 'magnum' do
         is_expected.to contain_oslo__messaging__notifications('magnum_config').with(
           :transport_url => '<SERVICE DEFAULT>',
           :driver        => '<SERVICE DEFAULT>',
-          :topics        => '<SERVICE DEFAULT>')
+          :topics        => '<SERVICE DEFAULT>',
+          :retry         => '<SERVICE DEFAULT>',
+        )
       end
 
     end
@@ -68,6 +72,7 @@ describe 'magnum' do
           :notification_transport_url         => 'rabbit://user:pass@host:1234/virt',
           :notification_topics                => 'openstack',
           :notification_driver                => 'messagingv1',
+          :notification_retry                 => 10,
           :default_transport_url              => 'rabbit://user:pass@host:1234/virt',
           :rpc_response_timeout               => '120',
           :control_exchange                   => 'magnum',
@@ -76,12 +81,14 @@ describe 'magnum' do
           :rabbit_heartbeat_timeout_threshold => 60,
           :rabbit_heartbeat_rate              => 10,
           :rabbit_heartbeat_in_pthread        => true,
+          :rabbit_qos_prefetch_count          => 0,
           :amqp_durable_queues                => true,
           :rabbit_quorum_queue                => true,
           :rabbit_transient_quorum_queue      => true,
           :rabbit_quorum_delivery_limit       => 3,
           :rabbit_quorum_max_memory_length    => 5,
           :rabbit_quorum_max_memory_bytes     => 1073741824,
+          :rabbit_enable_cancel_on_failover   => false,
         }
       end
 
@@ -104,6 +111,7 @@ describe 'magnum' do
           :heartbeat_timeout_threshold     => 60,
           :heartbeat_rate                  => 10,
           :heartbeat_in_pthread            => true,
+          :rabbit_qos_prefetch_count       => 0,
           :rabbit_use_ssl                  => '<SERVICE DEFAULT>',
           :kombu_reconnect_delay           => '<SERVICE DEFAULT>',
           :kombu_failover_strategy         => 'shuffle',
@@ -118,6 +126,7 @@ describe 'magnum' do
           :rabbit_quorum_delivery_limit    => 3,
           :rabbit_quorum_max_memory_length => 5,
           :rabbit_quorum_max_memory_bytes  => 1073741824,
+          :enable_cancel_on_failover       => false,
         )
       end
 
@@ -125,7 +134,9 @@ describe 'magnum' do
         is_expected.to contain_oslo__messaging__notifications('magnum_config').with(
           :transport_url => 'rabbit://user:pass@host:1234/virt',
           :driver        => 'messagingv1',
-          :topics        => 'openstack')
+          :topics        => 'openstack',
+          :retry         => 10,
+        )
       end
     end
 
@@ -186,61 +197,6 @@ describe 'magnum' do
         )
       end
     end
-    context 'with default amqp parameters' do
-      it 'configures amqp' do
-        is_expected.to contain_oslo__messaging__amqp('magnum_config').with(
-          :server_request_prefix  => '<SERVICE DEFAULT>',
-          :broadcast_prefix       => '<SERVICE DEFAULT>',
-          :group_request_prefix   => '<SERVICE DEFAULT>',
-          :container_name         => '<SERVICE DEFAULT>',
-          :idle_timeout           => '<SERVICE DEFAULT>',
-          :trace                  => '<SERVICE DEFAULT>',
-          :ssl_ca_file            => '<SERVICE DEFAULT>',
-          :ssl_cert_file          => '<SERVICE DEFAULT>',
-          :ssl_key_file           => '<SERVICE DEFAULT>',
-          :ssl_key_password       => '<SERVICE DEFAULT>',
-          :sasl_mechanisms        => '<SERVICE DEFAULT>',
-          :sasl_config_dir        => '<SERVICE DEFAULT>',
-          :sasl_config_name       => '<SERVICE DEFAULT>',
-          :username               => '<SERVICE DEFAULT>',
-          :password               => '<SERVICE DEFAULT>')
-      end
-    end
-
-    context 'with overridden amqp parameters' do
-      let :params do
-        {  :default_transport_url => 'amqp://amqp_user:password@localhost:5672',
-          :amqp_idle_timeout     => '60',
-          :amqp_trace            => true,
-          :amqp_ssl_ca_file      => '/etc/ca.cert',
-          :amqp_ssl_cert_file    => '/etc/certfile',
-          :amqp_ssl_key_file     => '/etc/key',
-          :amqp_username         => 'amqp_user',
-          :amqp_password         => 'password',
-        }
-      end
-
-      it 'configures amqp' do
-        is_expected.to contain_oslo__messaging__amqp('magnum_config').with(
-          :server_request_prefix  => '<SERVICE DEFAULT>',
-          :broadcast_prefix       => '<SERVICE DEFAULT>',
-          :group_request_prefix   => '<SERVICE DEFAULT>',
-          :container_name         => '<SERVICE DEFAULT>',
-          :idle_timeout           => 60,
-          :trace                  => 'true',
-          :ssl_ca_file            => '/etc/ca.cert',
-          :ssl_cert_file          => '/etc/certfile',
-          :ssl_key_file           => '/etc/key',
-          :ssl_key_password       => '<SERVICE DEFAULT>',
-          :sasl_mechanisms        => '<SERVICE DEFAULT>',
-          :sasl_config_dir        => '<SERVICE DEFAULT>',
-          :sasl_config_name       => '<SERVICE DEFAULT>',
-          :username               => 'amqp_user',
-          :password               => 'password')
-        is_expected.to contain_oslo__messaging__default('magnum_config').with(
-          :transport_url        => 'amqp://amqp_user:password@localhost:5672')
-      end
-    end
   end
 
   on_supported_os({
